==> haskell-hxt-unicode-9.0.2.4-4-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-hxt-unicode.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hxt-unicode
version: 9.0.2.4
id: hxt-unicode-9.0.2.4-HrCDROnPAej3zADTzj2LSZ
key: hxt-unicode-9.0.2.4-HrCDROnPAej3zADTzj2LSZ
license: MIT
copyright: Copyright (c) 2010- Uwe Schmidt
maintainer: Uwe Schmidt <uwe@fh-wedel.de>
stability: Stable
homepage: https://github.com/UweSchmidt/hxt
synopsis: Unicode en-/decoding functions for utf8, iso-latin-* and other encodings
description:
    Unicode encoding and decoding functions for utf8, iso-latin-* and somes other encodings,
    used in the Haskell XML Toolbox.
    ISO Latin 1 - 16, utf8, utf16, ASCII are supported. Decoding
    is done with lazy functions, errors may be detected or ignored.
category: Text
author: Uwe Schmidt
exposed: True
indefinite: False
exposed-modules:
    Data.Char.IsoLatinTables Data.String.EncodingNames Data.String.UTF8
    Data.String.UTF8Decoding Data.String.Unicode
abi: 9d8af02717035a15677c8758b4f7327a
trusted: False
import-dirs: /usr/lib/ghc-8.2.1/site-local/hxt-unicode-9.0.2.4
library-dirs: /usr/lib/ghc-8.2.1/site-local/hxt-unicode-9.0.2.4
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.1/hxt-unicode-9.0.2.4
hs-libraries: HShxt-unicode-9.0.2.4-HrCDROnPAej3zADTzj2LSZ
depends:
    base-4.10.0.0 hxt-charproperties-9.2.0.1-DwMBWjhyRF1Ll697rODxMh
abi-depends: base-4.10.0.0=32d562aa6d04d35ac79a0f49c17325ff
             hxt-charproperties-9.2.0.1-DwMBWjhyRF1Ll697rODxMh=f123fbce30d0a477393b885fa468c37f
haddock-interfaces: /usr/share/doc/haskell-hxt-unicode/html/hxt-unicode.haddock
haddock-html: /usr/share/doc/haskell-hxt-unicode/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hxt-unicode-9.0.2.4-5-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-hxt-unicode.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hxt-unicode
version: 9.0.2.4
id: hxt-unicode-9.0.2.4-JQmH0brCxMfxlpeXEYE5
key: hxt-unicode-9.0.2.4-JQmH0brCxMfxlpeXEYE5
license: MIT
copyright: Copyright (c) 2010- Uwe Schmidt
maintainer: Uwe Schmidt <uwe@fh-wedel.de>
stability: Stable
homepage: https://github.com/UweSchmidt/hxt
synopsis: Unicode en-/decoding functions for utf8, iso-latin-* and other encodings
description:
    Unicode encoding and decoding functions for utf8, iso-latin-* and somes other encodings,
    used in the Haskell XML Toolbox.
    ISO Latin 1 - 16, utf8, utf16, ASCII are supported. Decoding
    is done with lazy functions, errors may be detected or ignored.
category: Text
author: Uwe Schmidt
exposed: True
indefinite: False
exposed-modules:
    Data.Char.IsoLatinTables Data.String.EncodingNames Data.String.UTF8
    Data.String.UTF8Decoding Data.String.Unicode
abi: 46e93b79a769bd2c42b608d189acd933
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/hxt-unicode-9.0.2.4
library-dirs: /usr/lib/ghc-8.2.2/site-local/hxt-unicode-9.0.2.4
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/hxt-unicode-9.0.2.4
hs-libraries: HShxt-unicode-9.0.2.4-JQmH0brCxMfxlpeXEYE5
depends:
    base-4.10.1.0 hxt-charproperties-9.2.0.1-AUb7E6mkZ2fDXtvIiRtV8v
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             hxt-charproperties-9.2.0.1-AUb7E6mkZ2fDXtvIiRtV8v=128140e73626722dd834f67c7ef8810c
haddock-interfaces: /usr/share/doc/haskell-hxt-unicode/html/hxt-unicode.haddock
haddock-html: /usr/share/doc/haskell-hxt-unicode/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
